=======
AuDoLab
=======



 With AuDoLab you can perform Latend Direchlet Allocation on highly imbalanced datasets.


* Free software: GNU General Public License v3
* Documentation: https://AuDoLab.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
